
From: Yoichi Yuasa <yuasa@hh.iij4u.or.jp>

This patch has fixed the following warnings.

arch/mips/kernel/genex.S:250:5: warning: "CONFIG_64BIT" is not defined
arch/mips/math-emu/cp1emu.c:1128:5: warning: "__mips64" is not defined
arch/mips/math-emu/cp1emu.c:1206:5: warning: "__mips64" is not defined
arch/mips/math-emu/cp1emu.c:1270:5: warning: "__mips64" is not defined
arch/mips/math-emu/cp1emu.c:323:5: warning: "__mips64" is not defined
arch/mips/math-emu/cp1emu.c:808:5: warning: "__mips64" is not defined
arch/mips/math-emu/cp1emu.c:953:5: warning: "__mips64" is not defined
arch/mips/mm/tlbex.c:519:5: warning: "CONFIG_64BIT" is not defined
include/asm/reg.h:73:5: warning: "CONFIG_64BIT" is not defined

Signed-off-by: Yoichi Yuasa <yuasa@hh.iij4u.or.jp>
Cc: Ralf Baechle <ralf@linux-mips.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/mips/kernel/genex.S    |    4 ++--
 arch/mips/math-emu/cp1emu.c |   12 ++++++------
 arch/mips/mm/tlbex.c        |    2 +-
 include/asm-mips/reg.h      |    2 +-
 4 files changed, 10 insertions(+), 10 deletions(-)

diff -puN arch/mips/kernel/genex.S~mips-fix-build-warnings arch/mips/kernel/genex.S
--- 25/arch/mips/kernel/genex.S~mips-fix-build-warnings	Mon Aug 29 14:31:48 2005
+++ 25-akpm/arch/mips/kernel/genex.S	Mon Aug 29 14:31:48 2005
@@ -244,10 +244,10 @@ NESTED(nmi_handler, PT_SIZE, sp)
 	   start with an n and gas will believe \n is ok ...  */
 	.macro	__BUILD_verbose	nexception
 	LONG_L	a1, PT_EPC(sp)
-#if CONFIG_32BIT
+#ifdef CONFIG_32BIT
 	PRINT("Got \nexception at %08lx\012")
 #endif
-#if CONFIG_64BIT
+#ifdef CONFIG_64BIT
 	PRINT("Got \nexception at %016lx\012")
 #endif
 	.endm
diff -puN arch/mips/math-emu/cp1emu.c~mips-fix-build-warnings arch/mips/math-emu/cp1emu.c
--- 25/arch/mips/math-emu/cp1emu.c~mips-fix-build-warnings	Mon Aug 29 14:31:48 2005
+++ 25-akpm/arch/mips/math-emu/cp1emu.c	Mon Aug 29 14:31:48 2005
@@ -320,7 +320,7 @@ static int cop1Emulate(struct pt_regs *x
 	case cop1_op:
 		switch (MIPSInst_RS(ir)) {
 
-#if __mips64 && !defined(SINGLE_ONLY_FPU)
+#if defined(__mips64) && !defined(SINGLE_ONLY_FPU)
 		case dmfc_op:
 			/* copregister fs -> gpr[rt] */
 			if (MIPSInst_RT(ir) != 0) {
@@ -805,7 +805,7 @@ static int fpu_emu(struct pt_regs *xcp, 
 		ieee754dp d;
 		ieee754sp s;
 		int w;
-#if __mips64
+#ifdef __mips64
 		s64 l;
 #endif
 	} rv;			/* resulting value */
@@ -950,7 +950,7 @@ static int fpu_emu(struct pt_regs *xcp, 
 		}
 #endif /* __mips >= 2 */
 
-#if __mips64 && !defined(SINGLE_ONLY_FPU)
+#if defined(__mips64) && !defined(SINGLE_ONLY_FPU)
 		case fcvtl_op:{
 			ieee754sp fs;
 
@@ -1125,7 +1125,7 @@ static int fpu_emu(struct pt_regs *xcp, 
 		}
 #endif
 
-#if __mips64 && !defined(SINGLE_ONLY_FPU)
+#if defined(__mips64) && !defined(SINGLE_ONLY_FPU)
 		case fcvtl_op:{
 			ieee754dp fs;
 
@@ -1203,7 +1203,7 @@ static int fpu_emu(struct pt_regs *xcp, 
 		break;
 	}
 
-#if __mips64 && !defined(SINGLE_ONLY_FPU)
+#if defined(__mips64) && !defined(SINGLE_ONLY_FPU)
 	case l_fmt:{
 		switch (MIPSInst_FUNC(ir)) {
 		case fcvts_op:
@@ -1267,7 +1267,7 @@ static int fpu_emu(struct pt_regs *xcp, 
 	case w_fmt:
 		SITOREG(rv.w, MIPSInst_FD(ir));
 		break;
-#if __mips64 && !defined(SINGLE_ONLY_FPU)
+#if defined(__mips64) && !defined(SINGLE_ONLY_FPU)
 	case l_fmt:
 		DITOREG(rv.l, MIPSInst_FD(ir));
 		break;
diff -puN arch/mips/mm/tlbex.c~mips-fix-build-warnings arch/mips/mm/tlbex.c
--- 25/arch/mips/mm/tlbex.c~mips-fix-build-warnings	Mon Aug 29 14:31:48 2005
+++ 25-akpm/arch/mips/mm/tlbex.c	Mon Aug 29 14:31:48 2005
@@ -516,7 +516,7 @@ static __init int rel_lo(long val)
 
 static __init void i_LA_mostly(u32 **buf, unsigned int rs, long addr)
 {
-#if CONFIG_64BIT
+#ifdef CONFIG_64BIT
 	if (!in_compat_space_p(addr)) {
 		i_lui(buf, rs, rel_highest(addr));
 		if (rel_higher(addr))
diff -puN include/asm-mips/reg.h~mips-fix-build-warnings include/asm-mips/reg.h
--- 25/include/asm-mips/reg.h~mips-fix-build-warnings	Mon Aug 29 14:31:48 2005
+++ 25-akpm/include/asm-mips/reg.h	Mon Aug 29 14:31:48 2005
@@ -70,7 +70,7 @@
 
 #endif
 
-#if CONFIG_64BIT
+#ifdef CONFIG_64BIT
 
 #define EF_R0			 0
 #define EF_R1			 1
_
